@@ -34,11 +34,12 @@ NOTE_TECHNIQUE_INDEX = 3
 
 class Synthesizer():
 
-    def __init__(self, schema_path):
+    def __init__(self, schema_path = "musicxml-3.1-dtd-xsd/schema/musicxml.xsd", title = "My awesome solo sheet"):
         # default values
         self.beat_duration = -1
         self.mzxml = None
         self.schema_path = schema_path
+        self.title = title;
 
     def save(self, techs_and_notes_list, downbeats_str_list, beat_str_list):
         if isinstance(techs_and_notes_list, list) and isinstance(beat_str_list, list) and isinstance(downbeats_str_list, list):
@@ -68,7 +69,7 @@ class Synthesizer():
         solola_format_data = self.annotate_rest_and_technique(edge_group_by_bar, tech_and_notes_nparray,
                                                               first_downbeat_onset_list, beat_duration)
 
-        return self.solola_to_xml(solola_format_data, "My awesome solo sheet")
+        return self.solola_to_xml(solola_format_data, self.title)
 
     #
     # fundamental read(parsing) functions & Write file
